//
// See the file LICENSE for redistribution information.
//
// Copyright (c) 2002
//	Sleepycat Software.  All rights reserved.
//

#ifndef __INDEXMANAGER_HPP
#define __INDEXMANAGER_HPP

#include "Portability.hpp"
#include <string>
#include "Database.hpp"

namespace Sleepycat
{

class DatabaseManager
{
public:
	enum DatabaseId
	{
		CONFIGURATION,
		DOCUMENT_PRIMARY, 
		DOCUMENT_SECONDARY, 
		DICTIONARY_PRIMARY, 
		DICTIONARY_SECONDARY, 
		DICTIONARY_STATISTICS,
		SIZE
	};
	DatabaseManager(DbEnv *environment, u_int32_t flags);
	~DatabaseManager();

	/// Open/Create a Database.
	int open(DbTxn *txn, DatabaseId databaseid, const std::string& containername, u_int32_t flags, Database *&database);

	/// Get a reference to a Database.
	Database *get(DatabaseId databaseid) const;

private:
	// no need for copy and assignment
	DatabaseManager(const DatabaseManager&);
	void operator = (const DatabaseManager &);

	std::vector<Database *> databases;
	DbEnv *environment;
	u_int32_t databaseCreationFlags;

	struct databaseDefinition
	{
		DatabaseId databaseId;
		Database::Type databaseType;
		bool duplicates;
		char *databasename;
	};
	static databaseDefinition databaseDefinitions[];
};

}

#endif

